/**
 * Relbit flock
 * Replaces standard flock() and fclose() functions with it's own implementation
 * so the locks work properly on NFS.
 * 
 * Developed by Jakub Skokan <aither@havefun.cz> for Relbit LLC
 */

#ifndef PHP_RELBIT_FLOCK_H
#define PHP_RELBIT_FLOCK_H 1
#define PHP_RELBIT_FLOCK_VERSION "1.0"
#define PHP_RELBIT_FLOCK_EXTNAME "relbit_flock"

#ifdef ZTS
#include "TSRM.h"
#endif

ZEND_BEGIN_MODULE_GLOBALS(relbit_flock)
	char *lock_dir;
	long timeout;
	zval *locks;
ZEND_END_MODULE_GLOBALS(relbit_flock)

#ifdef ZTS
#define RELBIT_FLOCK_G(v) TSRMG(relbit_flock_globals_id, zend_relbit_flock_globals *, v)
#else
#define RELBIT_FLOCK_G(v) (relbit_flock_globals.v)
#endif

char* php_relbit_get_sha256(char *str);
int php_relbit_replace_function(char *what, char *with);
int php_relbit_get_link_target(long fd, char *target, int size);
int php_relbit_unlock(char *target, char *path, char *hex_digest);

PHP_FUNCTION(relbit_flock);
PHP_FUNCTION(relbit_fclose);
PHP_MINIT_FUNCTION(relbit_flock);
PHP_MSHUTDOWN_FUNCTION(relbit_flock);
PHP_RINIT_FUNCTION(relbit_flock);
PHP_MINFO_FUNCTION(relbit_flock);

extern zend_module_entry relbit_flock_module_entry;
#define phpext_relbit_flock_ptr &relbit_flock_module_entry

#endif

